@@ -5,16 +5,16 @@
    Copyright (C) 2000 Eazel, Inc.
   
    This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
+   modify it under the terms of the GNU Library General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.
   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
+   Library General Public License for more details.
   
-   You should have received a copy of the GNU General Public
+   You should have received a copy of the GNU Library General Public
    License along with this program; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
@@ -220,6 +220,7 @@ eel_debug_draw_rectangle_and_cross (GdkDrawable *drawable,
 				    gboolean draw_cross)
 {
 	GdkGC *gc;
+	GdkColor color_gdk = { 0 };
 
 	int width;
 	int height;
@@ -232,7 +233,14 @@ eel_debug_draw_rectangle_and_cross (GdkDrawable *drawable,
 
  	gc = gdk_gc_new (drawable);
  	gdk_gc_set_function (gc, GDK_COPY);
-	gdk_rgb_gc_set_foreground (gc, color);
+	
+	color_gdk.red   = ((color >> 16) & 0xff) << 8;
+	color_gdk.green = ((color >>  8) & 0xff) << 8;
+	color_gdk.blue  = ((color      ) & 0xff) << 8;
+	gdk_colormap_alloc_color (
+		gdk_drawable_get_colormap (drawable),
+		&color_gdk, FALSE, FALSE);
+	gdk_gc_set_rgb_fg_color (gc, &color_gdk);
 	
 	gdk_draw_rectangle (drawable,
 			    gc,
@@ -258,7 +266,7 @@ eel_debug_draw_rectangle_and_cross (GdkDrawable *drawable,
 			       rectangle.y0 + height - 1);
 	}
 
-	gdk_gc_unref (gc);
+	g_object_unref (gc);
 }
 
 /**
